<?php
/**
 * The template for displaying header
 */
global $wpdb;
$table_name = $wpdb->prefix . "webmac_social_links";

// Get social links
$sql = 'SELECT * FROM ' . $table_name;
$social = $wpdb->get_results($sql);

// Get help windows
$table_name = $wpdb->prefix . "webmac_windows";
$sql = 'SELECT slug, title FROM ' . $table_name . ' WHERE show_in_help = 1 AND status = 1 ORDER BY order_id ASC';
$help_items = $wpdb->get_results($sql);

// Theme options
$settings = get_site_option('webmac_settings');
$slider = get_site_option('webmac_slider_background');
?>

<div class="header" id="header">
    <div class="header__left">
        <?php if( ! is_front_page() ): ?>
        <a href="<?php echo site_url(); ?>">
            <i class="fab fa-apple header__logo"></i>
        </a>
        <?php else: ?>
            <i class="fab fa-apple header__logo"></i>
        <?php endif; ?>


        <?php if( $help_items || has_nav_menu('header-nav') ): ?>
        <a class="header__nav-toggle" href="#" role="button" id="nav_toggle">
            <i class="fas fa-bars"></i>
        </a>

        <ul class="nav" id="nav">
            <?php if($help_items): ?>
            <li class="nav__item">
                <span class="nav__link"><?php _e('Help', 'webmac' ); ?></span>

                <ul class="nav__sub">
                    <?php foreach($help_items as $help): ?>
                    <li class="nav__sub-item">
                        <a class="nav__sub-link" href="#window_<?php echo esc_html($help->slug); ?>" data-toggle="window"><?php echo esc_html(stripslashes($help->title)); ?></a>
                    </li>
                    <?php endforeach; ?>
                </ul>
            </li>
            <?php endif; ?>

            <?php if ( has_nav_menu('header-pages') ): ?>
            <li class="nav__item">
                <?php
                    $menu_location = 'header-pages';
                    $menu_locations = get_nav_menu_locations();
                    $menu_object = (isset($menu_locations[$menu_location]) ? wp_get_nav_menu_object($menu_locations[$menu_location]) : null);
                    $menu_name = (isset($menu_object->name) ? $menu_object->name : '');

                    echo '<span class="nav__link">' . esc_html($menu_name) . '</span>';

                    wp_nav_menu(array(
                        'theme_location'  => 'header-pages',
                        'container'       => 'ul',
                        'menu_class'      => 'nav__sub'
                    ));
                ?>
            </li>
            <?php endif; ?>

            <?php if ( has_nav_menu('header-categories') ): ?>
            <li class="nav__item">
                <?php
                    $menu_location = 'header-categories';
                    $menu_locations = get_nav_menu_locations();
                    $menu_object = (isset($menu_locations[$menu_location]) ? wp_get_nav_menu_object($menu_locations[$menu_location]) : null);
                    $menu_name = (isset($menu_object->name) ? $menu_object->name : '');

                    echo '<span class="nav__link">' . esc_html($menu_name) . '</span>';

                    wp_nav_menu(array(
                        'theme_location'  => 'header-categories',
                        'container'       => 'ul',
                        'menu_class'      => 'nav__sub'
                    ));
                ?>
            </li>
            <?php endif; ?>
        </ul><!-- /.nav -->
        <?php endif; ?>

    </div><!-- /.header__left -->

    <div class="header__right">
        <?php if($social): ?>
        <div class="social">
            <?php foreach($social as $soc): ?>
            <a class="social__item" href="<?php echo esc_url($soc->url); ?>" target="_blank">
                <i class="<?php echo esc_html($soc->icon); ?>"></i>
            </a>
            <?php endforeach; ?>
        </div><!-- /.social -->
        <?php endif; ?>

        <?php if($settings['lang'] == 1): ?>
        <div class="lang">
            <span class="lang__link">
                <span class="flag-icon flag-icon-gb"></span>
                <!-- List of flags: http://flag-icon-css.lip.is/ -->
            </span>

            <ul class="lang__list hide"><!-- To show lang dropdown remove class "hide" -->
                <li class="lang__item">
                    <a class="lang__link" href="#">
                        <span class="flag-icon flag-icon-ru"></span>
                        <span class="lang__text"><?php _e( 'Russian', 'webmac' ); ?></span>
                    </a>
                </li>
                <li class="lang__item">
                    <a class="lang__link" href="#">
                        <span class="flag-icon flag-icon-fr"></span>
                        <span class="lang__text"><?php _e( 'French', 'webmac' ); ?></span>
                    </a>
                </li>
            </ul>
        </div><!-- /.lang -->
        <?php endif; ?>

        <?php if($settings['time'] == 1): ?>
        <span class="time" id="time"></span>
        <?php endif; ?>

        <?php if($settings['search'] == 1): ?>
        <a class="header__search" id="search_toggle" href="#">
            <i class="fas fa-search"></i>
        </a>
        <?php endif; ?>

        <?php if($settings['sidebar'] == 1): ?>
        <a class="news__toggle" id="news_toggle" href="#">
            <?php _e( 'Sidebar Toggle', 'webmac' ); ?>
        </a>
        <?php endif; ?>
    </div><!-- /.header__right -->
</div><!-- /.header -->
