<?php

// Webmac setup
function webmac_setup() {
    // Theme support
    add_theme_support( 'menus' );
    register_nav_menu('header-pages', __( 'Header Pages' ));
    register_nav_menu('header-categories', __( 'Header Categories' ));

    add_theme_support( 'automatic-feed-links' );
    add_theme_support( 'title-tag' );

    add_theme_support( 'post-thumbnails', array( 'post' ) );
    set_post_thumbnail_size( 1200, 9999 );

    add_theme_support( 'post-formats', array(
        'gallery'
    ) );

    if ( ! isset( $content_width ) ) {
        $content_width = "100%";
    }

    // Default options
    add_option('webmac_settings', array(
        'time' => 1,
        'sidebar' => 1,
        'search' => 1,
        'preloader' => 1,
        'greeting' => 1,
        'lang' => 1,
        'rtl' => 0,
        'twitter_username' => '',
        'google_map_api' => ''
    ), "", "no");

    add_option('webmac_theme_options', array(
        'color_scheme' => 'theme_light'
    ), "", "no");

    add_option('webmac_slider_background', array(
        'slider' => 0,
        'gallery_id' => 0,
        'trans_speed' => 1000,
        'autoplay_speed' => 8000,
        'bg_color' => '#3e3e3e'
    ), "", "no");
}
add_action( 'after_setup_theme', 'webmac_setup' );


// Add lightbox for images with url
function webmac_images_lightbox($content) {
       global $post;
       $pattern ="/<a(.*?)href=('|\")(.*?).(bmp|gif|jpeg|jpg|png)('|\")(.*?)>/i";
       $replacement = '<a$1href=$2$3.$4$5 data-lightbox="photo_' . $post->ID . '" $6>';
       $content = preg_replace($pattern, $replacement, $content);
       return $content;
}
add_filter('the_content', 'webmac_images_lightbox');


// Remove gallery default styles
add_filter( 'use_default_gallery_style', '__return_false' );


// Hide admin bar on website
add_filter('show_admin_bar', '__return_false');


// Register and add styles and javascript
function webmac_scripts() {
    $theme = get_option('webmac_theme_options');
    $settings = get_option('webmac_settings');
    $slider = get_option('webmac_slider_background');

    wp_enqueue_style('webmac-style', get_template_directory_uri() . '/style.css');
    wp_enqueue_style('webmac-theme', get_template_directory_uri() . '/assets/css/' . $theme['color_scheme'] . ".css");

    if($settings['preloader'] == "1") wp_enqueue_script('webmac-preloader', get_template_directory_uri() . '/assets/js/preloader.js', '', '', true);
    wp_enqueue_script('webmac-js', get_template_directory_uri() . '/assets/js/main.js', '', '', true);

    $inline_css = "
    .desktop { background-color: {$slider['bg_color']}; }
    .desktop { background-image: url({$slider['bg_image']}); }
    ";
    wp_add_inline_style( 'webmac-style', $inline_css );

    $translation_array = array( 'templateUrl' => get_template_directory_uri() );
    wp_localize_script( 'webmac-js', 'object_name', $translation_array );
}
add_action('wp_enqueue_scripts', 'webmac_scripts');


// Widget init
function webmac_widgets_init() {

    // Register sidebar
    register_sidebar( array(
        'name'          => __( 'Sidebar', 'webmac' ),
        'id'            => 'sidebar',
        'description'   => __( 'Add widgets here to appear in your sidebar.', 'webmac' ),
        'before_widget' => '<section id="%1$s" class="widget %2$s">',
        'after_widget'  => '</section>',
        'before_title'  => '<h2 class="news__title">',
        'after_title'   => '</h2>',
    ) );

    // Remove default widgets register
    unregister_widget('WP_Widget_Search');
    unregister_widget('WP_Widget_Recent_Posts');
    unregister_widget('WP_Widget_Meta');
    unregister_widget('WP_Widget_Categories');
    unregister_widget('WP_Widget_Archives');
    unregister_widget('WP_Widget_Recent_Comments');
}
add_action( 'widgets_init', 'webmac_widgets_init' );


// Comments form order
function webmac_reorder_comment_fields( $fields ) {
    $new_fields = array();

    $myorder = array('author', 'email', 'url', 'comment');

    foreach( $myorder as $key ){
        $new_fields[ $key ] = $fields[ $key ];
        unset( $fields[ $key ] );
    }

    if( $fields )
        foreach( $fields as $key => $val )
            $new_fields[ $key ] = $val;

    return $new_fields;
}
add_filter( 'comment_form_fields', 'webmac_reorder_comment_fields' );


// Update comment field
function my_update_comment_field( $comment_field ) {

  $comment_field =
    '<p class="comment-form-comment">
            <label for="comment">' . __( "Comment", "text-domain" ) . '</label>
            <textarea required id="comment" name="comment" placeholder="' . esc_attr__( "Type your comment here...", "text-domain" ) . '" cols="45" rows="8" aria-required="true"></textarea>
        </p>';

  return $comment_field;
}
add_filter( 'comment_form_field_comment', 'my_update_comment_field' );
