<?php
/*
Plugin Name: WebMac Forms
Description: Get forms data from website (contact, request, reviews)
Author: BrainsCloud
Version: 1.0
Author URI: https://themeforest.net/user/brainscloud
*/

function webmac_forms_scripts() {
    wp_enqueue_style('style', plugins_url('/css/style.css', __FILE__ ));
    wp_enqueue_style('fontawesome', plugins_url('/css/fontawesome-all.min.css', __FILE__ ));
}
add_action('admin_print_styles', 'webmac_forms_scripts');


/**
** Plugin Activation
**/
function webmac_forms_activate() {
    global $wpdb;
    $table_name = $wpdb->prefix . "webmac_forms";

    create_forms_tables($table_name);
}

// Add section to admin menu
function webmac_forms_menu() {
    add_menu_page(
        'WebMac Forms',
        'WM Forms',
        'manage_options',
        'webmac_forms',
        'webmac_forms',
        plugin_dir_url(__FILE__) . 'menu-icon.png',
        null
    );
}
add_action('admin_menu', 'webmac_forms_menu');


/**
** Create database table and add default data on first activation
**/
function create_forms_tables($table_name) {
    global $wpdb;

    $charset_collate = $wpdb->get_charset_collate();

    if($wpdb->get_var("show tables like '$table_name'") != $table_name) {
        $sql = "CREATE TABLE IF NOT EXISTS $table_name (
            id int(11) UNSIGNED NOT NULL AUTO_INCREMENT,
            type smallint(2) UNSIGNED NOT NULL,
            name varchar(100) NOT NULL,
            email varchar(100) NOT NULL,
            tel varchar(50) NOT NULL,
            text text NOT NULL,
            rating smallint(1) UNSIGNED NOT NULL,
            status smallint(1) UNSIGNED NOT NULL,
            date datetime NOT NULL,
            PRIMARY KEY (id)
        ) $charset_collate;";

        require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
        dbDelta($sql);
    }
}
register_activation_hook( __FILE__, 'webmac_forms_activate' );



/**
** Form data list / Delete
**/
function webmac_forms($id = NULL) {
    if(is_admin()) {
        global $wpdb;
        $table_name = $wpdb->prefix . "webmac_forms";

        if(isset($_GET['view'])) {
            // View data
            $id = intval($_GET['view']);

            $sql = 'SELECT * FROM ' . $table_name . ' WHERE id = ' . $id;
            $data = $wpdb->get_row($sql);

            // Change status
            if( isset($_POST['request_status']) ) {
                $status = intval($_POST['request_status']);

                $wpdb->update(
                    $table_name,
                    array(
                        'status' => $status
                    ),
                    array('id' => $id)
                );

                wp_redirect("admin.php?page=webmac_forms&view=" . $id);
                exit;
            }

            include('view.php');
        } else if(isset($_GET['del'])) {
            // Delete data
            $id = intval($_GET['del']);
            $wpdb->delete(
                $table_name,
                [ 'id' => $id ],
                [ '%d' ]
            );

            wp_redirect("admin.php?page=webmac_forms");
            exit;
        } else {
            // Get forms data
            $page_num = isset( $_GET['pagenum'] ) ? absint( $_GET['pagenum'] ) : 1;
            $limit = 20;
            $offset = ( $page_num - 1 ) * $limit;
            $total = $wpdb->get_var( "SELECT COUNT(*) FROM  $table_name" );
            $num_of_pages = ceil( $total / $limit );
            $forms_data = $wpdb->get_results("SELECT * FROM $table_name ORDER BY id DESC LIMIT $offset, $limit" );

            $page_links = paginate_links( array(
                'base' => add_query_arg( 'pagenum', '%#%' ),
                'prev_text' => __( '«' ),
                'next_text' => __( '»' ),
                'total' => $num_of_pages,
                'current' => $page_num
            ) );

            include('list.php');
        }
    }
}
