<?php
/*
Plugin Name: WebMac Social Links
Description: Add social links to website header
Author: BrainsCloud
Version: 1.0
Author URI: https://themeforest.net/user/brainscloud
*/

function webmac_social_scripts() {
    wp_enqueue_style('webmac-social-style', plugins_url('/css/style.css', __FILE__ ));
    wp_enqueue_style('webmac-social-fontawesome', plugins_url('/css/fontawesome-all.min.css', __FILE__ ));
}
add_action('admin_print_styles', 'webmac_social_scripts');


/**
** Plugin Activation
**/
function webmac_social_activate() {
    global $wpdb;
    $table_name = $wpdb->prefix . "webmac_social_links";

    create_social_tables($table_name);
}

// Add section to admin menu
function webmac_social_menu() {
    add_menu_page(
        'WebMac Social Links',
        'WM Social',
        'manage_options',
        'webmac_social',
        'webmac_social',
        plugin_dir_url(__FILE__) . 'menu-icon.png',
        null
    );
}
add_action('admin_menu', 'webmac_social_menu');


/**
** Create database table and add default data on first activation
**/
function create_social_tables($table_name) {
    global $wpdb;

    $charset_collate = $wpdb->get_charset_collate();

    if($wpdb->get_var("show tables like '$table_name'") != $table_name) {
        $sql = "CREATE TABLE IF NOT EXISTS $table_name (
            id smallint(5) UNSIGNED NOT NULL AUTO_INCREMENT,
            icon varchar(55) NOT NULL,
            url varchar(255) NOT NULL,
            PRIMARY KEY (id)
        ) $charset_collate;";

        require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
        dbDelta($sql);
    }
}
register_activation_hook( __FILE__, 'webmac_social_activate' );



/**
** Social List & Add Social
**/
function webmac_social($id = NULL) {
    if(is_admin()) {
        global $wpdb;
        $table_name = $wpdb->prefix . "webmac_social_links";

        // Social delete
        if(isset($_GET['del'])) {
            $id = intval($_GET['del']);
            $wpdb->delete(
                $table_name,
                [ 'id' => $id ],
                [ '%d' ]
            );

            wp_redirect("admin.php?page=webmac_social");
            exit;
        }

        // Add social link
        if( isset($_POST['add_social']) ) {
            if( !empty($_POST['social_icon']) && !empty($_POST['social_url']) ) {
                $social = sanitize_text_field($_POST['social_icon']);
                $url = sanitize_text_field($_POST['social_url']);

                $wpdb->insert(
                    $table_name,
                    array(
                        'icon' => $social,
                        'url' => $url,
                    )
                );
            } else {
                $error_msg = "Please add link";
            }
        }

        // Get social links
        $sql = 'SELECT * FROM ' . $table_name . ' ORDER BY id DESC';
        $social = $wpdb->get_results($sql);

        include('view.php');
    }
}
