<?php
/*
Plugin Name: WebMac Windows
Description: Create mac windows on website
Author: BrainsCloud
Version: 1.0
Author URI: https://themeforest.net/user/brainscloud
*/


function webmac_windows_scripts() {
    wp_enqueue_style('webmac-windows-style', plugins_url('/css/style.css', __FILE__ ));
}
add_action('admin_print_styles', 'webmac_windows_scripts');


function webmac_window_icon_uploader() {
    wp_enqueue_media();
}
add_action("admin_enqueue_scripts", "webmac_window_icon_uploader");

function webmac_windows_output_buffer() {
    ob_start();
}
add_action('init', 'webmac_windows_output_buffer');

/**
** Plugin Activation
**/
function webmac_windows_activate() {
    global $wpdb;
    $table_name = $wpdb->prefix . "webmac_windows";

    create_windows_tables($table_name);
}

// Add section to admin menu
function webmac_windows_menu() {
    add_menu_page(
        'WebMac Windows',
        'WM Windows',
        'manage_options',
        'webmac_windows_list',
        'webmac_windows_list',
        plugin_dir_url(__FILE__) . 'img/menu-icon.png',
        null
    );

    add_submenu_page(
        'webmac_windows_list',
        'Add Window',
        'Add Window',
        'manage_options',
        'webmac_windows_add',
        'webmac_windows_add'
    );
}
add_action('admin_menu', 'webmac_windows_menu');


/**
** Create database table and add default data on first activation
**/
function create_windows_tables($table_name) {
    global $wpdb;

    $charset_collate = $wpdb->get_charset_collate();

    if($wpdb->get_var("show tables like '$table_name'") != $table_name) {
        $sql = "CREATE TABLE IF NOT EXISTS $table_name (
            id smallint(5) UNSIGNED NOT NULL AUTO_INCREMENT,
            title varchar(55) NOT NULL,
            slug varchar(55) NOT NULL,
            size tinyint(1) UNSIGNED DEFAULT '0' NOT NULL,
            text text NOT NULL,
            icon varchar(255) NOT NULL,
            fullscreen tinyint(1) UNSIGNED DEFAULT '1' NOT NULL,
            minimize tinyint(1) UNSIGNED DEFAULT '1' NOT NULL,
            resize tinyint(1) UNSIGNED DEFAULT '1' NOT NULL,
            centered tinyint(1) UNSIGNED DEFAULT '0' NOT NULL,
            status tinyint(1) UNSIGNED DEFAULT '1' NOT NULL,
            show_in_dock tinyint(1) UNSIGNED DEFAULT '1' NOT NULL,
            show_in_help tinyint(1) UNSIGNED DEFAULT '0' NOT NULL,
            order_id tinyint(3) UNSIGNED DEFAULT '1' NOT NULL,
            allow_delete tinyint(1) UNSIGNED DEFAULT '1' NOT NULL,
            PRIMARY KEY (id)
        ) $charset_collate;";

        require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
        dbDelta($sql);
        add_windows_data($table_name);
    }
}

/**
** Default data on first activation
**/
function add_windows_data($table_name) {
    global $wpdb;

    $windows_data = array();

    $windows_data[0] = array(
        'title' => 'Services',
        'slug' => 'default_services',
        'size' => 2,
        'text' => '[webmac_services][webmac_services_item photo="https://placehold.it/400x600" title="WebSite development" price="from $599"]Lorem ipsum dolor sit amet, consectetur adipisicing elit. Saepe nobis ex, ipsa delectus itaque accusamus ad debitis laborum ab cupiditate voluptatibus possimus quasi, nisi quo ducimus dolorem, maiores vel voluptas![/webmac_services_item][/webmac_services][webmac_services_form]',
        'icon' => plugin_dir_url(__FILE__) . 'img/icons/services.png',
        'allow_delete' => 0,
        'order_id' => 1
    );

    $windows_data[1] = array(
        'title' => 'About Us',
        'slug' => 'default_about',
        'text' => '<h1>H1 title Numquam dolor distinctio repellendus reprehenderit?</h1><p>Lorem ipsum dolor sit amet, consectetur adipisicing elit. Numquam dolor distinctio repellendus reprehenderit? Eveniet numquam voluptatem, mollitia nobis, perferendis voluptatibus nostrum quibusdam rerum ea reiciendis facere, pariatur itaque. Enim, illum.</p><p><img src="https://placehold.it/2000x400" alt=""></p>',
        'icon' => plugin_dir_url(__FILE__) . 'img/icons/notes.png',
        'allow_delete' => 0,
        'order_id' => 2
    );

    $windows_data[2] = array(
        'title' => 'Team',
        'slug' => 'default_team',
        'text' => '[webmac_team][webmac_team_member photo="https://placehold.it/150" name="Marie Oswald" job="Designer" email="marie@mail.com" phone="+9981258124"]Lorem ipsum dolor sit amet, consectetur adipisicing elit. Hic nobis, dignissimos porro facilis inventore quae dolorem earum fuga autem.[/webmac_team_member][/webmac_team]',
        'icon' => plugin_dir_url(__FILE__) . 'img/icons/podcast.png',
        'allow_delete' => 0,
        'order_id' => 3
    );

    $windows_data[3] = array(
        'title' => 'Gallery',
        'slug' => 'default_gallery',
        'text' => '<h3>Gallery</h3><p>Add gallery using media button</p>',
        'icon' => plugin_dir_url(__FILE__) . 'img/icons/photos.png',
        'allow_delete' => 0,
        'order_id' => 4
    );

    $windows_data[4] = array(
        'title' => 'Reviews',
        'slug' => 'default_reviews',
        'text' => '[webmac_reviews] [webmac_reviews_add success="Thanks for your review!" danger="Fill up the form, please!" error="Something go wrong. Try again later!"]',
        'icon' => plugin_dir_url(__FILE__) . 'img/icons/messages.png',
        'allow_delete' => 0,
        'order_id' => 5
    );

    $windows_data[5] = array(
        'title' => 'Documents',
        'slug' => 'default_docs',
        'text' => '[webmac_docs]
[webmac_docs_item href="#link_to_file" icon="https://placehold.it/50" title="Document.pdf"]
[/webmac_docs]',
        'icon' => plugin_dir_url(__FILE__) . 'img/icons/folder.png',
        'allow_delete' => 0,
        'order_id' => 6
    );

    $windows_data[6] = array(
        'title' => 'How To Find Us',
        'slug' => 'default_map',
        'text' => '[webmac_map lat="40.7020338" long="-73.9403548" zoom="13" title="Your company title" address="New York, Street 121" worktime="10:00 - 21:00" phone="+987123654" email="info@mail.com"]',
        'icon' => plugin_dir_url(__FILE__) . 'img/icons/maps.png',
        'size' => 2,
        'allow_delete' => 0,
        'order_id' => 7
    );

    $windows_data[7] = array(
        'title' => 'Contacts',
        'slug' => 'default_contacts',
        'text' => '[webmac_contact_form success="Thanks for your question, we reply you soon!" danger="Fill up the form, please!" error="Something go wrong. Try again later!"]',
        'icon' => plugin_dir_url(__FILE__) . 'img/icons/mail.png',
        'allow_delete' => 0,
        'order_id' => 8
    );

    $windows_data[8] = array(
        'title' => 'Info',
        'slug' => 'default_info',
        'size' => 1,
        'text' => '[webmac_tabs_nav]
[webmac_tabs_nav_item active="true" title="About Company" target="info_about"]
[webmac_tabs_nav_item active="false" title="Address and Requisites" target="address_req"]
[/webmac_tabs_nav]

[webmac_tabs_content]

[webmac_tabs_item active="true" id="info_about"]

[webmac_about_info photo="https://placehold.it/150" title="Company title"]

<p>Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry\'s standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book.</p>

<p>It has survived not only five centuries, but also the leap into electronic typesetting, remaining essentially unchanged.</p>

<p>It was popularised in the 1960s with the release of Letraset sheets containing Lorem Ipsum passages, and more recently with desktop publishing software like Aldus PageMaker including versions of Lorem Ipsum.</p>[/webmac_about_info]

[/webmac_tabs_item]

[webmac_tabs_item active="false" id="address_req"]

<h4>Address & Requisites</h4>
<p>Lorem ipsum dolor sit amet, consectetur adipisicing elit. Quas expedita molestias est adipisci impedit, labore, excepturi iure cumque officiis quaerat? Ipsum quod vel architecto ea quae, veritatis nemo enim nihil! iure cumque officiis quaerat? Ipsum quod vel architecto ea quae, veritatis nemo enim nihil!</p>
<p>Address: New York City, Street 121</p>
<p>Email: info@mail.com</p>
<p>Phone: +9983247272</p>
[/webmac_tabs_item]

[/webmac_tabs_content]',
        'icon' => plugin_dir_url(__FILE__) . 'img/icons/dictionary.png',
        'centered' => 1,
        'fullscreen' => 0,
        'minimize' => 0,
        'resize' => 0,
        'show_in_dock' => 0,
        'show_in_help' => 1,
        'allow_delete' => 0,
        'order_id' => 9
    );

    $windows_data[9] = array(
        'title' => 'Hotkeys',
        'slug' => 'default_hotkeys',
        'size' => 1,
        'text' => '<div class="text-s"><p>Click <span class="code">alt + m</span> to minimize active window</p>
    <p>Click <span class="code">alt + f</span> to run fullscreen active window</p>
    <p>Click <span class="code">esc</span> to exit from fullscreen mode</p>
    <p>Click <span class="code">esc</span> to exit from gallery</p>
    <p>Click <span class="code">alt + q</span> to close active window</p>
    <p>Click <span class="code">alt + a</span> to close alert</p>
    <p>Click <span class="code">alt + n</span> show/close sidebar</p>
    <p>Click <span class="code">alt + s</span> show/close search</p>
    <p>Right Click on dock item, when window is active, will run context menu</p>
    <p>Swipe alert message to close it</p></div>',
        'icon' => plugin_dir_url(__FILE__) . 'img/icons/reminders.png',
        'centered' => 1,
        'fullscreen' => 0,
        'minimize' => 0,
        'resize' => 0,
        'show_in_dock' => 0,
        'show_in_help' => 1,
        'allow_delete' => 0,
        'order_id' => 10
    );

    foreach ($windows_data as $window) {
        $wpdb->insert(
            $table_name,
            $window
        );
    }
}
register_activation_hook( __FILE__, 'webmac_windows_activate' );



/**
** Windows List/Edit/Delete
**/
function webmac_windows_list() {
    if(is_admin()) {
        global $wpdb;
        $table_name = $wpdb->prefix . "webmac_windows";

        if(isset($_GET['edit'])) {
            // Edit window
            $id = intval($_GET['edit']);

            if( isset($_POST['save_window']) ) {
                if( !empty($_POST['window_title']) && !empty($_POST['window_text']) && !empty($_POST['window_icon']) ) {
                    $data = get_window_form_values();

                    $wpdb->update(
                        $table_name,
                        array(
                            'title' => $data['title'],
                            'size' => $data['size'],
                            'text' => $data['text'],
                            'icon' => $data['icon'],
                            'fullscreen' => $data['fullscreen'],
                            'minimize' => $data['minimize'],
                            'resize' => $data['resize'],
                            'centered' => $data['centered'],
                            'show_in_dock' => $data['dock'],
                            'show_in_help' => $data['help'],
                            'status' => $data['status'],
                            'order_id' => $data['order_id']
                        ),
                        array('id' => $id)
                    );
                } else {
                    $error_msg = "Please fill up title, text and upload icon!";
                }
            }

            $sql = 'SELECT * FROM ' . $table_name . ' WHERE id = ' . $id;
            $window_info = $wpdb->get_row($sql);

            include('inc/edit.php');
        } else if(isset($_GET['del'])) {
            // Delete window
            $id = intval($_GET['del']);
            $wpdb->delete(
                $table_name,
                [ 'id' => $id, 'allow_delete' => 1 ],
                [ '%d', '%d' ]
            );

            wp_redirect("admin.php?page=webmac_windows_list");
            exit;
        } else {
            $sql = 'SELECT * FROM ' . $table_name . ' ORDER BY order_id ASC';
            $windows = $wpdb->get_results($sql);

            include('inc/list.php');
        }
    }
}



/**
** Add Window
**/
function webmac_windows_add() {
    if(is_admin()) {

        global $wpdb;
        $table_name = $wpdb->prefix . "webmac_windows";

        if( isset($_POST['add_window']) ) {

            if(!empty($_POST['window_title']) && !empty($_POST['window_text']) && !empty($_POST['window_icon'])) {
                $data = get_window_form_values();

                $wpdb->insert(
                    $table_name,
                    array(
                        'title' => $data['title'],
                        'slug' => $data['slug'],
                        'size' => $data['size'],
                        'text' => $data['text'],
                        'icon' => $data['icon'],
                        'fullscreen' => $data['fullscreen'],
                        'minimize' => $data['minimize'],
                        'resize' => $data['resize'],
                        'centered' => $data['centered'],
                        'show_in_dock' => $data['dock'],
                        'show_in_help' => $data['help'],
                        'status' => $data['status'],
                        'order_id' => $data['order_id']
                    ),
                    array( "%s", "%s", "%d", "%s", "%s", "%d", "%d", "%d", "%d", "%d", "%d" )
                );
                $window_id = $wpdb->insert_id;
                wp_redirect("admin.php?page=webmac_windows_list&edit=" . $window_id);
                exit;
            } else {
                $error_msg = "Please fill up title, text and upload icon!";
            }
        }
        include('inc/add.php');
    }
}


function get_window_form_values() {
    $title = sanitize_text_field($_POST['window_title']);
    $slug = sanitize_title_for_query($_POST['window_slug']);
    $size = intval($_POST['window_size']);
    $text = $_POST['window_text'];
    $icon = htmlspecialchars($_POST['window_icon']);
    $order_id = intval($_POST['window_order']);

    $fullscreen = (isset($_POST['window_fullscreen']) && $_POST['window_fullscreen'] == "on") ? 1 : 0;
    $minimize = (isset($_POST['window_minimize']) && $_POST['window_minimize'] == "on") ? 1 : 0;
    $resize = (isset($_POST['window_resize']) && $_POST['window_resize'] == "on") ? 1 : 0;
    $centered = (isset($_POST['window_centered']) && $_POST['window_centered'] == "on") ? 1 : 0;
    $dock = (isset($_POST['window_show_in_dock']) && $_POST['window_show_in_dock'] == "on") ? 1 : 0;
    $help = (isset($_POST['window_show_in_help']) && $_POST['window_show_in_help'] == "on") ? 1 : 0;
    $status = (isset($_POST['window_status']) && $_POST['window_status'] == "on") ? 1 : 0;

    $data = array(
        'title' => $title,
        'slug' => $slug,
        'size' => $size,
        'text' => $text,
        'icon' => $icon,
        'fullscreen' => $fullscreen,
        'minimize' => $minimize,
        'resize' => $resize,
        'centered' => $centered,
        'dock' => $dock,
        'help' => $help,
        'status' => $status,
        'order_id' => $order_id
    );

    return $data;
}
